@@ -1,3 +1,4 @@
+use std::fmt::{Debug, Formatter};
 use crate::portfolio::error::PortfolioError;
 use crate::portfolio::position::Position;
 use crate::portfolio::repository::error::RepositoryError;
@@ -22,6 +23,12 @@ pub struct RedisRepository {
     conn: Connection,
 }
 
+impl Debug for RedisRepository {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("RedisRepository").finish()
+    }
+}
+
 impl PositionHandler for RedisRepository {
     fn set_position(
         &mut self,
